      subroutine breprt

C**************************************************
C
C This subroutine prints out diagnostic information
C on all of the parameters which bruce uses to perform
C its pulsation calculations.
C
C Started :19/9/95
C Modified:11/10/95
C          23/12/98 - Added reporting on new INCLUDE_ENDPOINTS switch
C          23/12/98 - Added reporting on new WRITE_TIMINGS_FILE switch
C
C (c) Richard Townsend 1995
C
C**************************************************

C Turn off implicit typing

      implicit none

C Define the hard-wired parameters

      include "bruce.compar_define.inc"

C Load in the Stellar parameters common block

      include "bruce.stepar_common.inc"

C Load in the Mode definition common block

      include "bruce.moddef_common.inc"

C Load in the file names common block

      include "bruce.filnam_common.inc"

C Load in the Field definition common block

      include "bruce.flddef_common.inc"

C Load in the Field switches common block

      include "bruce.fldswi_common.inc"

C Load in the equilibrium stellar grid common block

      include "bruce.eqstgr_common.inc"

C Declare the in-program variables

      integer modcnt			! Counts over the modes

C Bung in the constants and angles include files

      include "constants.inc"
      include "angles.inc"

C OK, we now have all of the parameters read in. We now proceed to print them
C out in a nice big display...

      write(chandl,'(48X,''Mode Definitions'')')
      write(chandl,'(5X,A)') '-----------------------------
     :-----------------------------------------------------
     :---------------------------------------------'
      write(chandl,'(5X,
     :''Mode# L-Val M-Val Vel-Ampl  K-Value
     :  K-Theory CPeriod  OPeriod  NA-Factor NA-Shift Phase
     :  Mag-dT/T Nu-Val Parity J-Val roAp-Amp'')')
      write(chandl,'(5X,A)') '-----------------------------
     :-----------------------------------------------------
     :---------------------------------------------'
    
C Loop through the modes, using modcnt for the counter
 
      do modcnt=1,NModes,1
        write(chandl,'(6X,I3,3X,I3,3X,I3,3X,F6.2,4X,
     :  F5.2,4X,F5.2,3X,F8.3,X,F8.3,1X,F5.2,5X,
     :  F5.2,5X,F4.2,3X,F7.1,2X,F5.2,2X,L,6X,I3,3X,F6.4)')
     :  modcnt,Lmode(modcnt),Mmode(modcnt),
     :  VAmode(modcnt)/1000.D0,Kmode(modcnt),
     :  Gpole/(Rpole*CFmode(modcnt)**2),
     :  D360/(CFmode(modcnt)*3600.D0),
     :  D360/((CFmode(modcnt)-Mmode(modcnt)*Omega)*3600.D0),
     :  AAmode(modcnt),APmode(modcnt),IPmode(modcnt),
     :  (Gamma-1.D0)/(Gamma)*
     :  (Kmode(modcnt)*Lmode(modcnt)*(Lmode(modcnt)+1.D0)
     :  -4.D0-1.D0/Kmode(modcnt))*AAmode(modcnt),
     :  2.D0*Omega/CFmode(modcnt),parity(modcnt),JMode(modcnt),
     :  NAmode(modcnt)
      enddo

      write(chandl,'(5X,A)') '-----------------------------
     :-----------------------------------------------------
     :---------------------------------------------'
                                        
C Print out the general parameters

      write(chandl,'('' '')')
      write(chandl,'(47X,''General Parameters'')')
      write(chandl,'(5X,A)') '-----------------------------
     :-----------------------------------------------------
     :---------------------------------------------'
      write(chandl,'(13X,''Polar Radius         :'',F6.3,24X,
     :''Equatorial Radius      :'',F7.3)') RPole/RSun, REq/RSun
      write(chandl,'(13X,''Equal Area Radius    :'',F6.3,24X,
     :''Equal Volume Radius    :'',F7.3)')
     :  sqrt(AStar/(4.D0*pi))/RSun,
     : (VStar*3.D0/(4.D0*pi))**(1./3.)/RSun
      write(chandl,'(13X,''Polar Temperature    :'',I6,24X,
     :''Equatorial Temperature :'',I7)') int(TPole),int(TEq)
      write(chandl,'(13X,''Polar Gravity dex    :'',F6.3,24X,
     :''Equatorial Gravity dex :'',F7.3)') log10(GPole)+2.D0,
     : log10(GEq)+2.D0
      write(chandl,'(13X,''Stellar Mass         :'',F6.3,24X,
     :''Stellar Luminosity dex :'',F7.3)') MStar/MSun,
     :  log10(LStar/LSun)
      write(chandl,'(13X,''Rotation Period      :'',F10.3,20X,
     :''Equatorial Velocity    :'',F7.3)') D360/(Omega*3600.D0),
     : VEq/1000.D0
      write(chandl,'(13X,''Critical Percentage  :'',F6.3,24X,
     :''Polar Inclination      :'',F7.3)') VEq/VCrit, 
     : DIncl*360/(D360)
      write(chandl,'('' '')')
      write(chandl,'(13X,''Number of Fields     :'',I3)') NField
      write(chandl,'(13X,''Visible Grid Points  :'',I5,25X,
     :''Field-Dump Filestub    :'',A)') GrdVis,DmStub
      write(chandl,'(13X,''Total Grid Points    :'',I5,25X,
     :''Write Auxilary Files   :'',L1)') GrdTot,WrtAux
      write(chandl,'(13X,''Start Time           :'',F6.3,24X,
     :''Input Timings Filename :'',A)') Times(1)/3600.D0,TmFile
      write(chandl,'(13X,''Finish Time          :'',F6.3,24X,
     :''Write Timings File     :'',L1)') Times(NField)/3600.D0,WrtTim
      write(chandl,'(13X,''Lee & Saio Modes     :'',L1,29X,
     :''Lee & Saio Matrix Dim  :'',I3)') LSDEff,MatDim
      write(chandl,'(13X,''roAp Off-Axis Support:'',L1,29X,
     :''Primary Axis Offset    :'',F7.3)') roAEff,RAxOff/D360*360.D0
      write(chandl,'(13X,''Fields are Radial    :'',L1,29X,
     :''Fields are Normal      :'',L1)') .not.GrvFld,GrvFld
      write(chandl,'(13X,''Surface Area Effects :'',L1,29X,
     :''Surface Normal Effects :'',L1)') SrfEff,NrmEff
      write(chandl,'(13X,''Temperature Effects  :'',L1,29X,
     :''Horizontal Vel. Fields :'',L1)') TmpEff,HorEff
      write(chandl,'(5X,A)') '-----------------------------
     :-----------------------------------------------------
     :---------------------------------------------'

C Quit out...

      return

      end
