      function lsdfhor(m,ctheta,n,np,
     :                  vhor,parity)

C***************************************************
C
C This function returns the horizontal velocity
C function of Lee & Saio's Lambda basis (ApJ 1990)
C The horizontal (neglecting toroidal) velocity field
C of an NRP eigenstate is then the horizontal gradient
C of this function. This routine calculates the eigenstate
C for an azimuthal quantum number m and a corresponding
C set of expansion coeffs vhor(1:n) which has physical dimension np.
C These coeffs are previously calculated using lsdvhor.
C parity defines whether this is done for odd or even modes.
C
C This routine should now be able to handle m=0 bum-outs
C
C  This function now adheres to the Condon & Shortley phase convention
C
C Stated:29/3/95
C Last Modified:6/12/95
C
C (c) Richard Townsend 1995
C
C*****************************************************

      implicit none		! Turn off implicit typing

C Declare the passed variables

      double precision lsdfhor	! The returned function
      double precision ctheta	! The cos(theta) value to use
      integer m			! The m-value to use
      integer n			! The number of terms to sum over
      integer np		! The total size of vhor
      double precision vhor(np)	! The column vector containg the coefficients
      logical parity		! The parity to be used - .true.=even

C Declare the in-program variables

      integer j			! The summation counter
      integer lj    		! Holds l-values for Pml's
      integer am		! The absoulte value of m
      integer CSphas		! The Condon & Shortley phase adjustor
      double precision Pml	! The value of the Assoc. Leg. Poly, l=lj
      double precision Pml1	! The value of the Assoc. Leg. Poly, l=lj+1
      double precision stheta	! Sine of theta
      double precision oddfac	! The product of all odd integers lt (2m-1)

C Set up am=|m|
                             
      am=iabs(m)      

C Set up CSPhas

      CSPhas=(-1)**((am-m)/2)

C Initialise the staring values of Pml and Pml1
C oddfac has to be used along the way for Pml - see
C Numerical Recipies 2nd Ed p247

      stheta=dsqrt((1.D0-ctheta)*(1.D0+ctheta))
      oddfac=1.D0

      Pml=1.D0

      if (am.gt.0) then

        do j=1,am
          Pml=-Pml*oddfac*stheta
          oddfac=oddfac+2.D0
        enddo

      endif

C Fix the phase to be that of Condon & Shortley

      Pml=Pml*CSPhas

C Set up Pml1

      Pml1=ctheta*(2*am+1)*Pml

C First initialise the total sum, including the extra
C eigval and 1/(lj(lj+1)) bits.

      if(parity) then
        lsdfhor=vhor(1)*Pml
      else
        lsdfhor=vhor(1)*Pml1
      endif

C And now loop over j to get the rest of the sum...

      do j=2,n

C Update Pml - first get the l-value for this update,
C and then bung its new value into Pml. 

        lj=am+2*(j-1)

        Pml=(ctheta*(2*lj-1)*Pml1
     :      -(lj+am-1)*Pml)/(lj-am)

C Now update the value of Pml1, again doing lj

        lj=am+1+2*(j-1)

        Pml1=(ctheta*(2*lj-1)*Pml
     :       -(lj+am-1)*Pml1)/(lj-am)

C Now we add in the appropiate term to the sum, depending
C on the parity...

        if(parity) then
          lsdfhor=lsdfhor+vhor(j)*Pml
        else
          lsdfhor=lsdfhor+vhor(j)*Pml1
        endif

C Its as simple as that - now loop back around....

      enddo

C Thats all folks - return...

      return

      end
